# RunKMC
Tool for simulating polymerization using a Kinetic Monte Carlo algorithm.

Core is written in c++ within a thin Python wrapper.

## Quick install

The simplest way to install **RunKMC** is via pip:

```shell
pip3 install runkmc
```



## Examples

Tutorial notebooks can be found in the documentation.

## How to Cite

When using RunKMC in your project, please cite:

## Third-Party Licenses
This software includes the Eigen library (MPL2 license).
See the [Eigen license](./cpp/include/eigen-3.4.0/eigen-3.4.0/LICENSE) in the codebase for details.
